@@ -20,7 +20,7 @@ use PPIx::QuoteLike::Utils qw{
 
 use base qw{ PPIx::QuoteLike::Token };
 
-our $VERSION = '0.016';
+our $VERSION = '0.022';
 
 sub ppi {
     my ( $self ) = @_;
@@ -76,7 +76,7 @@ sub variables {
 
 sub __perl_version_introduced {
     my ( $self ) = @_;
-    $self->content() =~ m/ -> (?: \@ [[{*] | % [*] ) /smx
+    $self->{postderef}
 	and return '5.019005';
     return;
 }
@@ -158,7 +158,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2016-2021 by Thomas R. Wyant, III
+Copyright (C) 2016-2022 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
